MNIST dataset
=============

This section covers the MNIST use case. This use case has been implemented using three
different strategies, ``TensorFlow``, ``PyTorch`` and ``PyTorch Lightning``. You can 
find the files relevant to this use case
in the `use case's folder on Github <https://github.com/interTwin-eu/itwinai/tree/main/use-cases/mnist>`_.

For more information on each implementation, consult their respective READMEs:

Torch Lightning
---------------

.. include:: ../../use-cases/mnist/torch-lightning/README.md
   :parser: myst_parser.sphinx_
   :start-line: 2


PyTorch
-------

.. include:: ../../use-cases/mnist/torch/README.md
   :parser: myst_parser.sphinx_
   :start-line: 2
